@@ -1,9 +1,10 @@
 import re
 import sys
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
 from django.core import urlresolvers
+from django.core.exceptions import ImproperlyConfigured
 from functools import update_wrapper
+from inspect import isclass
 from utkik.utils import import_string, cached_property
 
 
@@ -21,6 +22,9 @@ class ViewWrapper(object):
 
     def __init__(self, view):
         self.view = view
+        if not hasattr(view, '__name__') and isinstance(view, object):
+            # for class instances that use call
+            view.__name__ = view.__class__.__name__
         update_wrapper(self, view)
 
     @property
@@ -43,10 +47,14 @@ class ViewWrapper(object):
         useful for view classes in the raised exception.
         """
         try:
-            if hasattr(self.view, 'dispatch'):
-                return self.view().dispatch(request, *args, **kwargs)
-            elif callable(self.view):
-                return self.view(request, *args, **kwargs)
+            if isclass(self.view):
+                view = self.view()
+                if hasattr(view, 'dispatch'):
+                    return view.dispatch(request, *args, **kwargs)
+            else:
+                view = self.view
+            if callable(view):
+                return view(request, *args, **kwargs)
         except Exception, e:
             try:
                 cls, e, trace = sys.exc_info()
@@ -57,7 +65,7 @@ class ViewWrapper(object):
             else:
                 raise cls(msg), None, trace
         raise ImproperlyConfigured('%s.%s does not define a view function or '
-            'class.' % (self.view.__module__, self.view.__name__))
+            'class view.' % (self.view.__module__, self.view.__name__))
 
     def __getattr__(self, name):
         return getattr(self.view, name)
@@ -68,13 +76,13 @@ class LazyViewWrapper(ViewWrapper):
     Lazy import wrapper for a view function or class.
     """
 
-    def __init__(self, import_name):
-        module, name = import_name.rsplit('.', 1)
+    def __init__(self, dot_name):
+        module, name = dot_name.rsplit('.', 1)
         if module in settings.INSTALLED_APPS:
             module += '.views'
         self.__module__ = module
         self.__name__ = name
-        self.import_name = '%s.%s' % (module, name)
+        self.dot_name = '%s.%s' % (module, name)
 
     @cached_property
     def view(self):
@@ -83,7 +91,7 @@ class LazyViewWrapper(ViewWrapper):
         view class that this is not an instance but the class, instantiation
         will be done in the ``__call__`` method.
         """
-        view = import_string(self.import_name)
+        view = import_string(self.dot_name)
         self.__doc__ = view.__doc__
         return view
 
